==> jsword-1.0.3-src.zip: jsword-1.0.3-20060724/jsword/org/crosswire/jsword/book/filter/thml/IgnoreTag.java <==
/**
 * Distribution License:
 * JSword is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License, version 2.1 as published by
 * the Free Software Foundation. This program is distributed in the hope
 * that it will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * The License is available on the internet at:
 *       http://www.gnu.org/copyleft/lgpl.html
 * or by writing to:
 *      Free Software Foundation, Inc.
 *      59 Temple Place - Suite 330
 *      Boston, MA 02111-1307, USA
 *
 * Copyright: 2005
 *     The copyright to this program is held by it's authors.
 *
 * ID: $Id: IgnoreTag.java 1004 2006-02-14 21:26:27Z dmsmith $
 */
package org.crosswire.jsword.book.filter.thml;


/**
 * THML Tag to process the pb element.
 * 
 * @see gnu.lgpl.License for license details.
 *      The copyright to this program is held by it's authors.
 * @author Joe Walker [joe at eireneh dot com]
 */
public class IgnoreTag extends AbstractTag
{
    /**
     * Simple ctor
     */
    public IgnoreTag(String name)
    {
        this.name = name;
    }

    /* (non-Javadoc)
     * @see org.crosswire.jsword.book.filter.thml.Tag#getTagName()
     */
    public String getTagName()
    {
        return name;
    }

    /**
     * The tag name that we are ignoring
     */
    private String name;
}

==> jsword-1.0.6-src.zip: jsword-1.0.6/jsword/org/crosswire/jsword/book/filter/thml/IgnoreTag.java <==
/**
 * Distribution License:
 * JSword is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License, version 2.1 as published by
 * the Free Software Foundation. This program is distributed in the hope
 * that it will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * The License is available on the internet at:
 *       http://www.gnu.org/copyleft/lgpl.html
 * or by writing to:
 *      Free Software Foundation, Inc.
 *      59 Temple Place - Suite 330
 *      Boston, MA 02111-1307, USA
 *
 * Copyright: 2005
 *     The copyright to this program is held by it's authors.
 *
 * ID: $Id: IgnoreTag.java 1174 2006-10-22 00:44:33Z dmsmith $
 */
package org.crosswire.jsword.book.filter.thml;


/**
 * THML Tag to process the content of an element but to ignore the tag itself.
 * 
 * @see gnu.lgpl.License for license details.
 *      The copyright to this program is held by it's authors.
 * @author Joe Walker [joe at eireneh dot com]
 */
public class IgnoreTag extends AbstractTag
{
    /**
     * Simple ctor
     */
    public IgnoreTag(String name)
    {
        this.name = name;
    }

    /* (non-Javadoc)
     * @see org.crosswire.jsword.book.filter.thml.Tag#getTagName()
     */
    public String getTagName()
    {
        return name;
    }

    /**
     * The tag name that we are ignoring
     */
    private String name;
}
